@@ -107,10 +107,26 @@ class User:
             return
         r=s.get('https://www.luogu.com.cn/api/chat/record?user='+str(uid),headers=headers)
         return r.json()['messages']
+    
+    def sendMessage(self,uid,content):
+        s=self.sess
+        if(not s):
+            print('请先登录!')
+            return
+        postData={
+            'content':content,
+            'user':uid,
+        }
+        return s.post('https://www.luogu.com.cn/api/chat/new',headers=headers,data=postData).json()
         
 def getUid(name):
     r=requests.get('https://www.luogu.com.cn/api/user/search?keyword='+name,headers=headers).json()
     if(r['users'][0]):
         return str(r['users'][0]['uid'])
     else:
-        return '-1'
\ No newline at end of file
+        return '-1'
+        
+def searchProblem(keyword,page,diffi=0):
+    r=requests.get('https://www.luogu.com.cn/problem/list?keyword='+keyword+('&difficulty='+str(diffi) if diffi!=-1 else '')+'&page='+str(page)+'&_contentOnly=1',headers=headers)
+    return r.json()['currentData']
+    
\ No newline at end of file
